package App::lcpan::Cmd::authordists;

our $DATE = '2015-04-07'; # DATE
our $VERSION = '0.14'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{':package'} = {
    v => 1.1,
    summary => "'authordists' command",
};

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => 'List distributions of an author',
    args => {
        %App::lcpan::common_args,
        %App::lcpan::author_args,
        %App::lcpan::flatest_args,
    },
    result_naked=>1,
};
sub handle_cmd {
    my %args = @_;

    App::lcpan::list_local_cpan_dists(%args);
}

1;
# ABSTRACT: 'authordists' command

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authordists - 'authordists' command

=head1 VERSION

This document describes version 0.14 of App::lcpan::Cmd::authordists (from Perl distribution App-lcpan), released on 2015-04-07.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> any

List distributions of an author.

Arguments ('*' denotes required arguments):

=over 4

=item * B<author>* => I<str>

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=item * B<latest> => I<bool>

=back

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
