package App::lcpan::Cmd::authors_by_rel_count;

our $DATE = '2015-04-07'; # DATE
our $VERSION = '0.14'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{':package'} = {
    v => 1.1,
    summary => "'authors-by-rel-count' command",
};

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => 'List authors ranked by number of releases',
    args => {
        %App::lcpan::common_args,
    },
    result_naked=>1,
};
sub handle_cmd {
    my %args = @_;

    App::lcpan::_set_args_default(\%args);
    my $cpan = $args{cpan};
    my $index_name = $args{index_name};

    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);

    my $sql = "SELECT
  cpanid id,
  (SELECT COUNT(*) FROM file WHERE cpanid=a.cpanid) AS rel_count
FROM author a
ORDER BY rel_count DESC
";

    my @res;
    my $sth = $dbh->prepare($sql);
    $sth->execute();
    while (my $row = $sth->fetchrow_hashref) {
        push @res, $row;
    }
    \@res;
}

1;
# ABSTRACT: 'authors-by-rel-count' command

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authors_by_rel_count - 'authors-by-rel-count' command

=head1 VERSION

This document describes version 0.14 of App::lcpan::Cmd::authors_by_rel_count (from Perl distribution App-lcpan), released on 2015-04-07.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> any

List authors ranked by number of releases.

Arguments ('*' denotes required arguments):

=over 4

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=back

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
